Module otter_lib

otter_lib module.

Description

otter_lib module. Exports common library functions for the otter otter_srv (otter server) applications.

Function Index

i32_to_ip/1Convert a 32 bit binary to ipv4 tuple {A,B,C,D}
id/0Generate 64 bit integer random ID.
ip_to_i32/1Convert ipv4 tuple {A,B,C,D} to 32 bit integer.
timestamp/0UNIX Timestamp in microseconds.
to_bin/1Convert various data types to binary format with unicode support where applicable.

Function Details

i32_to_ip/1

i32_to_ip(I32::binary()) -> ip4()

Convert a 32 bit binary to ipv4 tuple {A,B,C,D}

id/0

id() -> integer()

Generate 64 bit integer random ID

ip_to_i32/1

ip_to_i32(IP4::ip4()) -> integer()

Convert ipv4 tuple {A,B,C,D} to 32 bit integer

timestamp/0

timestamp() -> integer()

UNIX Timestamp in microseconds

to_bin/1

to_bin(Int::term()) -> binary()

Convert various data types to binary format with unicode support where applicable


Generated by EDoc, May 26 2017, 14:22:06.