Module otter_lib_zipkin_thrift

This module facilitates encoding/decoding of thrift data lists encoded with the binary protocol, suitable for sending/receiving spans on the zipkin interface.

Description

This module facilitates encoding/decoding of thrift data lists encoded with the binary protocol, suitable for sending/receiving spans on the zipkin interface.

Function Index

decode_spans/1Decodes a binary to a list of spans.
encode_spans/3Encodes a list of spans to a thrift (binary encoded) binary.

Function Details

decode_spans/1

decode_spans(BinaryData::binary()) -> [span()]

Decodes a binary to a list of spans.

encode_spans/3

encode_spans(Spans::[span()], ExtraTags::list(), ServiceDefaults::term()) -> binary()

Encodes a list of spans to a thrift (binary encoded) binary. ExtraTags is a list of key-value pairs that are added for each span in the list (e.g. the "lc" tag which tags the span with service information) in OpenZipkin. ServiceDefaults is used to complete the service information when only partial information is provided in span information e.g. default or only service name.


Generated by EDoc, May 26 2017, 14:22:06.