| i32_to_ip/1 | Convert a 32 bit binary to ipv4 tuple {A,B,C,D} |
| id/0 | Generate 64 bit integer random ID. |
| ip_to_i32/1 | Convert ipv4 tuple {A,B,C,D} to 32 bit integer. |
| timestamp/0 | UNIX Timestamp in microseconds. |
| to_bin/1 | Convert various data types to binary format with unicode support where applicable. |
i32_to_ip(I32::binary()) -> ip4()
Convert a 32 bit binary to ipv4 tuple {A,B,C,D}
id() -> integer()
Generate 64 bit integer random ID
ip_to_i32(IP4::ip4()) -> integer()
Convert ipv4 tuple {A,B,C,D} to 32 bit integer
timestamp() -> integer()
UNIX Timestamp in microseconds
to_bin(Int::term()) -> binary()
Convert various data types to binary format with unicode support where applicable
Generated by EDoc, May 26 2017, 14:22:06.