| finish/1 | Finish a span : add duration (current time - timestamp). |
| from_proplist/1 | Convert a proplist to span record. |
| get_duration/1 | Get the duration of a span. |
| get_id/1 | Get the id of a span. |
| get_ids/1 | Get ids (trace id and span id) of a span. |
| get_logs/1 | Get the list of logs (timestamp-text pairs) of a span. |
| get_name/1 | Get the name of a span. |
| get_parent_id/1 | Get the parent id of a span. |
| get_tags/1 | Get the list of tags (key-value pairs) of a span. |
| get_timestamp/1 | Get the start timestamp of a span. |
| get_trace_id/1 | Get the trace id of a span. |
| log/2 | Adds a log message to a span. |
| log/3 | Adds a log message to a span with the specified service information. |
| start/1 | Starts a span with the specified name. |
| start/2 | Starts a span with the specified name and trace id. |
| start/3 | Starts a child span with the specified name, trace id and parent id. |
| start_with_tags/2 | Starts a span with the specified name and initial tags. |
| start_with_tags/3 | Starts a span with the specified name, initial tags and trace id. |
| start_with_tags/4 | Starts a child span with the specified name, trace id and parent id. |
| tag/3 | Adds a tag to a span. |
| tag/4 | Adds a tag to a span with a given service. |
| to_proplist/1 | Convert span record to a proplist. |
Finish a span : add duration (current time - timestamp)
from_proplist(Proplist::list()) -> span()
Convert a proplist to span record. The proplist is expected to have keys : timestamp, duration, id, trace_id, parent_id, name, tags, logs with the correct values as described in the span record in otter.hrl
Get the duration of a span. Returns integer ter the span is finished otherwise undefined
Get the id of a span
get_ids(Span::span()) -> {trace_id(), span_id()}
Get ids (trace id and span id) of a span
Get the list of logs (timestamp-text pairs) of a span
Get the name of a span
Get the parent id of a span
Get the list of tags (key-value pairs) of a span
Get the start timestamp of a span
Get the trace id of a span
Adds a log message to a span.
Adds a log message to a span with the specified service information.
Starts a span with the specified name. Automatically generates a trace id.
start(Name::info(), TraceId::trace_id()) -> span()
Starts a span with the specified name and trace id
start(Name::info(), TraceId::trace_id(), ParentId::span_id()) -> span()
Starts a child span with the specified name, trace id and parent id
Starts a span with the specified name and initial tags.
start_with_tags(Name::info(), InitialTags::[tag()], TraceId::trace_id()) -> span()
Starts a span with the specified name, initial tags and trace id
start_with_tags(Name::info(), InitialTags::[tag()], TraceId::trace_id(), ParentId::span_id() | undefined) -> span()
Starts a child span with the specified name, trace id and parent id
Adds a tag to a span. If the tag already exists, its value will be overwritten.
Adds a tag to a span with a given service. If the tag already exists, its value will be overwritten.
to_proplist(Span::span()) -> list()
Convert span record to a proplist
Generated by EDoc, May 26 2017, 14:22:06.