| decode_spans/1 | Decodes a binary to a list of spans. |
| encode_spans/3 | Encodes a list of spans to a thrift (binary encoded) binary. |
decode_spans(BinaryData::binary()) -> [span()]
Decodes a binary to a list of spans.
encode_spans(Spans::[span()], ExtraTags::list(), ServiceDefaults::term()) -> binary()
Encodes a list of spans to a thrift (binary encoded) binary. ExtraTags is a list of key-value pairs that are added for each span in the list (e.g. the "lc" tag which tags the span with service information) in OpenZipkin. ServiceDefaults is used to complete the service information when only partial information is provided in span information e.g. default or only service name.
Generated by EDoc, May 26 2017, 14:22:06.